@@ -280,7 +280,6 @@ ClientNode *AddClientWindow(Window w, char alreadyMapped, char notOwner)
    ResetBorder(np);
 
    return np;
-
 }
 
 /** Minimize a client window and all of its transients. */
@@ -632,18 +631,20 @@ void SetClientDesktop(ClientNode *np, unsigned int desktop)
 
 }
 
-/** Hide a client without unmapping. This will not update transients. */
+/** Hide a client. This will not update transients. */
 void HideClient(ClientNode *np)
 {
-   if(activeClient == np) {
-      activeClient = NULL;
-   }
-   np->state.status |= STAT_HIDDEN;
-   if(np->state.status & (STAT_MAPPED | STAT_SHADED)) {
-      if(np->parent != None) {
-         JXUnmapWindow(display, np->parent);
-      } else {
-         JXUnmapWindow(display, np->window);
+   if(!(np->state.status & STAT_HIDDEN)) {
+      if(activeClient == np) {
+         activeClient = NULL;
+      }
+      np->state.status |= STAT_HIDDEN;
+      if(np->state.status & (STAT_MAPPED | STAT_SHADED)) {
+         if(np->parent != None) {
+            JXUnmapWindow(display, np->parent);
+         } else {
+            JXUnmapWindow(display, np->window);
+         }
       }
    }
 }
@@ -689,6 +690,10 @@ void MaximizeClient(ClientNode *np, MaxFlags flags)
       UnshadeClient(np);
    }
 
+   if(np->state.status & STAT_MINIMIZED) {
+      RestoreClient(np, 1);
+   }
+
    RaiseClient(np);
    FocusClient(np);
    if(np->state.maxFlags) {
@@ -1232,8 +1237,9 @@ void RemoveClient(ClientNode *np)
                             np->x, np->y, np->width, np->height);
       }
       GravitateClient(np, 1);
-      if(!(np->state.status & STAT_MAPPED)
-         && (np->state.status & (STAT_MINIMIZED | STAT_SHADED))) {
+      if((np->state.status & STAT_HIDDEN)
+         || (!(np->state.status & STAT_MAPPED)
+            && (np->state.status & (STAT_MINIMIZED | STAT_SHADED)))) {
          JXMapWindow(display, np->window);
       }
       JXUngrabButton(display, AnyButton, AnyModifier, np->window);
@@ -1405,6 +1411,7 @@ void SendConfigureEvent(ClientNode *np)
    Assert(np);
 
    memset(&event, 0, sizeof(event));
+   event.display = display;
    event.type = ConfigureNotify;
    event.event = np->window;
    event.window = np->window;
