@@ -20,11 +20,20 @@ extern struct ClientNode *nodes[LAYER_COUNT];
 /** Client windows in linked lists for each layer (pointer to the tail). */
 extern struct ClientNode *nodeTail[LAYER_COUNT];
 
+/** Determine if a client is on the current desktop.
+ * @param np The client.
+ * @return 1 if on the current desktop, 0 otherwise.
+ */
+#define IsClientOnCurrentDesktop( np ) \
+   ((np->state.desktop == currentDesktop) \
+      || (np->state.status & STAT_STICKY))
+
 /** Determine if a client is allowed focus.
  * @param np The client.
+ * @param current 1 if only showing clients on the current desktop.
  * @return 1 if focus is allowed, 0 otherwise.
  */
-char ShouldFocus(const struct ClientNode *np);
+char ShouldFocus(const struct ClientNode *np, char current);
 
 /** Start walking the window client list. */
 void StartWindowWalk(void);
@@ -45,4 +54,3 @@ void StopWindowWalk(void);
 void FocusNextStacked(struct ClientNode *np);
 
 #endif /* CLIENTLIST_H */
-
