@@ -371,6 +371,7 @@ void HandleButtonEvent(const XButtonEvent *event)
 
    np = FindClientByParent(event->window);
    if(np) {
+      /* Click on the border. */
       if(event->type == ButtonPress) {
          FocusClient(np);
          RaiseClient(np);
@@ -389,12 +390,16 @@ void HandleButtonEvent(const XButtonEvent *event)
       np = FindClientByWindow(event->window);
       if(np) {
          const char move_resize = (np->state.status & STAT_DRAG)
-            || ((mask == Mod1Mask) && !(np->state.status & STAT_NODRAG));
+            || ((mask == settings.moveMask)
+               && !(np->state.status & STAT_NODRAG));
          switch(event->button) {
          case Button1:
          case Button2:
             FocusClient(np);
-            RaiseClient(np);
+            if(settings.focusModel == FOCUS_SLOPPY
+               || settings.focusModel == FOCUS_CLICK) {
+               RaiseClient(np);
+            }
             if(move_resize) {
                GetBorderSize(&np->state, &north, &south, &east, &west);
                MoveClient(np, event->x + west, event->y + north);
@@ -407,7 +412,10 @@ void HandleButtonEvent(const XButtonEvent *event)
                             event->x + west, event->y + north);
             } else {
                FocusClient(np);
-               RaiseClient(np);
+               if(settings.focusModel == FOCUS_SLOPPY
+                  || settings.focusModel == FOCUS_CLICK) {
+                  RaiseClient(np);
+               }
             }
             break;
          default:
@@ -622,7 +630,6 @@ void HandleKeyRelease(const XKeyEvent *event)
 /** Process a configure request. */
 void HandleConfigureRequest(const XConfigureRequestEvent *event)
 {
-   XWindowChanges wc;
    ClientNode *np;
 
    if(HandleDockConfigureRequest(event)) {
@@ -705,12 +712,17 @@ void HandleConfigureRequest(const XConfigureRequestEvent *event)
 
       /* Return early if there's nothing to do. */
       if(!changed) {
+         /* Nothing changed; send a synthetic configure event. */
+         SendConfigureEvent(np);
          return;
       }
 
+      /* Stop any move/resize that may be in progress. */
       if(np->controller) {
          (np->controller)(0);
       }
+
+      /* If the client is maximized, restore it first. */
       if(np->state.maxFlags) {
          MaximizeClient(np, MAX_NONE);
       }
@@ -719,26 +731,30 @@ void HandleConfigureRequest(const XConfigureRequestEvent *event)
          resized = 1;
       }
       if(resized) {
+         /* The size changed so the parent will need to be redrawn. */
          ConstrainSize(np);
          ConstrainPosition(np);
          ResetBorder(np);
       } else {
+         /* Only the position changed; move the client. */
          int north, south, east, west;
          GetBorderSize(&np->state, &north, &south, &east, &west);
+
          if(np->parent != None) {
             JXMoveWindow(display, np->parent, np->x - west, np->y - north);
+            SendConfigureEvent(np);
          } else {
             JXMoveWindow(display, np->window, np->x, np->y);
          }
       }
 
-      SendConfigureEvent(np);
       RequirePagerUpdate();
 
    } else {
 
       /* We don't know about this window, just let the configure through. */
 
+      XWindowChanges wc;
       wc.stack_mode = event->detail;
       wc.sibling = event->above;
       wc.border_width = event->border_width;
@@ -774,7 +790,8 @@ void HandleEnterNotify(const XCrossingEvent *event)
    np = FindClient(event->window);
    if(np) {
       if(  !(np->state.status & STAT_ACTIVE)
-         && (settings.focusModel == FOCUS_SLOPPY)) {
+         && (settings.focusModel == FOCUS_SLOPPY
+            || settings.focusModel == FOCUS_SLOPPY_TITLE)) {
          FocusClient(np);
       }
       if(np->parent == event->window) {
@@ -1491,7 +1508,7 @@ void HandleUnmapNotify(const XUnmapEvent *event)
          RemoveClient(np);
       } else if((np->state.status & STAT_MAPPED) || event->send_event) {
          if(!(np->state.status & STAT_HIDDEN)) {
-            np->state.status &= ~STAT_MAPPED;
+            np->state.status &= ~(STAT_MAPPED | STAT_MINIMIZED | STAT_SHADED);
             JXUngrabButton(display, AnyButton, AnyModifier, np->window);
             GravitateClient(np, 1);
             JXReparentWindow(display, np->window, rootWindow, np->x, np->y);
