@@ -28,6 +28,7 @@ typedef enum {
    TOK_CLOCKSTYLE,
    TOK_CLOSE,
    TOK_CORNER,
+   TOK_DEFAULTICON,
    TOK_DESKTOP,
    TOK_DESKTOPS,
    TOK_DOCK,
@@ -76,9 +77,11 @@ typedef enum {
    TOK_STICK,
    TOK_SWALLOW,
    TOK_TASKLIST,
+   TOK_TASKLISTSTYLE,
    TOK_TEXT,
    TOK_TRAY,
    TOK_TRAYBUTTON,
+   TOK_TRAYBUTTONSTYLE,
    TOK_TRAYSTYLE,
    TOK_WIDTH,
    TOK_WINDOWSTYLE
