@@ -135,6 +135,8 @@ static const char *X_ATTRIBUTE = "x";
 static const char *Y_ATTRIBUTE = "y";
 static const char *WIDTH_ATTRIBUTE = "width";
 static const char *HEIGHT_ATTRIBUTE = "height";
+static const char *DYNAMIC_ATTRIBUTE = "dynamic";
+static const char *SPACING_ATTRIBUTE = "spacing";
 
 static const char *FALSE_VALUE = "false";
 static const char *TRUE_VALUE = "true";
@@ -387,8 +389,10 @@ void Parse(const TokenNode *start, int depth)
 /** Parse focus model. */
 void ParseFocusModel(const TokenNode *tp) {
    static const StringMappingType mapping[] = {
-      { "click",     FOCUS_CLICK    },
-      { "sloppy",    FOCUS_SLOPPY   }
+      { "click",        FOCUS_CLICK          },
+      { "clicktitle",   FOCUS_CLICK_TITLE    },
+      { "sloppy",       FOCUS_SLOPPY         },
+      { "sloppytitle",  FOCUS_SLOPPY_TITLE   }
    };
    settings.focusModel = ParseTokenValue(mapping, ARRAY_LENGTH(mapping), tp,
                                          settings.focusModel);
@@ -425,6 +429,10 @@ void ParseMoveMode(const TokenNode *tp)
    if(str) {
       settings.desktopDelay = ParseUnsigned(tp, str);
    }
+   str = FindAttribute(tp->attributes, "mask");
+   if(str && *str) {
+      settings.moveMask = ParseModifierString(str);
+   }
 
    settings.moveStatusType = ParseStatusWindowType(tp);
    settings.moveMode = ParseTokenValue(mapping, ARRAY_LENGTH(mapping), tp,
@@ -449,7 +457,7 @@ Menu *ParseMenu(const TokenNode *start)
    const char *value;
    Menu *menu;
 
-   menu = Allocate(sizeof(Menu));
+   menu = CreateMenu();
 
    value = FindAttribute(start->attributes, HEIGHT_ATTRIBUTE);
    if(value) {
@@ -481,6 +489,7 @@ void ParseRootMenu(const TokenNode *start)
 {
    Menu *menu;
    char *onroot;
+   const char *value;
 
    menu = ParseMenu(start);
 
@@ -489,6 +498,9 @@ void ParseRootMenu(const TokenNode *start)
       onroot = "123";
    }
 
+   value = FindAttribute(start->attributes, DYNAMIC_ATTRIBUTE);
+   menu->dynamic = CopyString(value);
+
    SetRootMenu(onroot, menu);
 
 }
@@ -559,7 +571,7 @@ MenuItem *ParseMenuItem(const TokenNode *start, Menu *menu, MenuItem *last)
          value = FindAttribute(start->attributes, TOOLTIP_ATTRIBUTE);
          last->tooltip = CopyString(value);
 
-         last->submenu = Allocate(sizeof(Menu));
+         last->submenu = CreateMenu();
          child = last->submenu;
 
          value = FindAttribute(start->attributes, HEIGHT_ATTRIBUTE);
@@ -1061,6 +1073,8 @@ void ParseTrayStyle(const TokenNode *tp, FontType font, ColorType fg)
       if(temp) {
          settings.listAllTasks = !strcmp(temp, "all");
       }
+   } else if(tp->type == TOK_TASKLISTSTYLE) {
+      ParseDecorations(tp, &settings.taskListDecorations);
    }
 
    for(np = tp->subnodeHead; np; np = np->next) {
@@ -1263,36 +1277,6 @@ void ParseTaskList(const TokenNode *tp, TrayType *tray)
    }
 }
 
-/** Parse the task list style. */
-void ParseTaskListStyle(const TokenNode *tp)
-{
-   const TokenNode *np;
-   for(np = tp->subnodeHead; np; np = np->next) {
-      switch(np->type) {
-      case TOK_FONT:
-         SetFont(FONT_TASKLIST, np->value);
-         break;
-      case TOK_ACTIVE:
-         ParseActive(np, COLOR_TASKLIST_ACTIVE_FG,
-                     COLOR_TASKLIST_ACTIVE_BG1, COLOR_TASKLIST_ACTIVE_BG2,
-                     COLOR_TASKLIST_ACTIVE_UP, COLOR_TASKLIST_ACTIVE_DOWN);
-         break;
-      case TOK_BACKGROUND:
-         ParseGradient(np->value, COLOR_TASKLIST_BG1, COLOR_TASKLIST_BG2);
-         break;
-      case TOK_FOREGROUND:
-         SetColor(COLOR_TASKLIST_FG, np->value);
-         break;
-      case TOK_OUTLINE:
-         ParseGradient(np->value, COLOR_TASKLIST_DOWN, COLOR_TASKLIST_UP);
-         break;
-      default:
-         InvalidTag(np, TOK_TASKLISTSTYLE);
-         break;
-      }
-   }
-}
-
 /** Parse the tray button style. */
 void ParseTrayButtonStyle(const TokenNode *tp)
 {
@@ -1491,6 +1475,11 @@ void ParseDock(const TokenNode *tp, TrayType *tray) {
       width = 0;
    }
 
+   str = FindAttribute(tp->attributes, SPACING_ATTRIBUTE);
+   if(str) {
+      settings.dockSpacing = ParseUnsigned(tp, str);
+   }
+
    cp = CreateDock(width);
    if(JLIKELY(cp)) {
       AddTrayComponent(tray, cp);
@@ -1740,13 +1729,25 @@ void ParseGroupOption(const TokenNode *tp, struct GroupType *group,
       const WinLayerType layer = ParseLayer(tp, option + 6);
       AddGroupOptionUnsigned(group, OPTION_LAYER, layer);
    } else if(!strncmp(option, "desktop:", 8)) {
-      const unsigned int desktop = (unsigned int)atoi(option + 8);
+      const unsigned desktop = (unsigned)atoi(option + 8);
       AddGroupOptionUnsigned(group, OPTION_DESKTOP, desktop);
    } else if(!strncmp(option, "icon:", 5)) {
       AddGroupOptionString(group, OPTION_ICON, option + 5);
    } else if(!strncmp(option, "opacity:", 8)) {
-      const unsigned int opacity = ParseOpacity(tp, option + 8);
+      const unsigned opacity = ParseOpacity(tp, option + 8);
       AddGroupOptionUnsigned(group, OPTION_OPACITY, opacity);
+   } else if(!strncmp(option, "x:", 2)) {
+      const int x = atoi(option + 2);
+      AddGroupOptionSigned(group, OPTION_X, x);
+   } else if(!strncmp(option, "y:", 2)) {
+      const int y = atoi(option + 2);
+      AddGroupOptionSigned(group, OPTION_Y, y);
+   } else if(!strncmp(option, "width:", 6)) {
+      const unsigned width = (unsigned)atoi(option + 6);
+      AddGroupOptionUnsigned(group, OPTION_WIDTH, width);
+   } else if(!strncmp(option, "height:", 7)) {
+      const unsigned height = (unsigned)atoi(option + 7);
+      AddGroupOptionUnsigned(group, OPTION_HEIGHT, height);
    } else {
       ParseError(tp, _("invalid Group Option: %s"), option);
    }
