@@ -189,6 +189,16 @@ char ShowRootMenu(int index, int x, int y, char keyboard)
    if(menuShown) {
       return 0;
    }
+   if (rootMenu[index]->dynamic) {
+      Menu *menu = ParseDynamicMenu(rootMenu[index]->dynamic);
+      if(menu) {
+         char ret;
+         InitializeMenu(menu);
+         ret = ShowMenu(menu, RunRootCommand, x, y, keyboard);
+         DestroyMenu(menu);
+         return ret;
+      }
+   }
    return ShowMenu(rootMenu[index], RunRootCommand, x, y, keyboard);
 }
 
