@@ -21,6 +21,7 @@ static void FixRange(unsigned int *value,
 /** Initialize settings. */
 void InitializeSettings(void)
 {
+   settings.moveMask = (1 << Mod1MapIndex);
    settings.doubleClickSpeed = 400;
    settings.doubleClickDelta = 2;
    settings.snapMode = SNAP_BORDER;
@@ -44,10 +45,12 @@ void InitializeSettings(void)
    settings.menuOpacity = UINT_MAX;
    settings.windowDecorations = DECO_FLAT;
    settings.trayDecorations = DECO_FLAT;
+   settings.taskListDecorations = DECO_UNSET;
    settings.menuDecorations = DECO_FLAT;
    settings.cornerRadius = 4;
    settings.groupTasks = 0;
    settings.listAllTasks = 0;
+   settings.dockSpacing = 0;
 }
 
 /** Make sure settings are reasonable. */
@@ -66,6 +69,11 @@ void StartupSettings(void)
    FixRange(&settings.desktopHeight, 1, 64, 1);
    settings.desktopCount = settings.desktopWidth * settings.desktopHeight;
 
+   if(settings.taskListDecorations == DECO_UNSET) {
+      settings.taskListDecorations = settings.trayDecorations;
+   }
+
+   FixRange(&settings.dockSpacing, 0, 64, 0);
 }
 
 /** Update a string setting. */
