@@ -70,8 +70,8 @@ void StartupTrayButtons(void)
    for(bp = buttons; bp; bp = bp->next) {
       if(bp->label) {
          bp->cp->requestedWidth
-            = GetStringWidth(FONT_TRAYBUTTON, bp->label) + 4;
-         bp->cp->requestedHeight = GetStringHeight(FONT_TRAYBUTTON);
+            = GetStringWidth(FONT_TRAY, bp->label) + 4;
+         bp->cp->requestedHeight = GetStringHeight(FONT_TRAY);
       } else {
          bp->cp->requestedWidth = 0;
          bp->cp->requestedHeight = 0;
@@ -79,12 +79,12 @@ void StartupTrayButtons(void)
       if(bp->iconName) {
          bp->icon = LoadNamedIcon(bp->iconName, 1, 1);
          if(JLIKELY(bp->icon)) {
-            bp->cp->requestedWidth += bp->icon->images->width + 4;
+            bp->cp->requestedWidth += bp->icon->width + 4;
             if(bp->label) {
                bp->cp->requestedWidth -= 2;
             }
             bp->cp->requestedHeight
-               = Max(bp->icon->images->height + 4, bp->cp->requestedHeight);
+               = Max(bp->icon->height + 4, bp->cp->requestedHeight);
          } else {
             Warning(_("could not load tray icon: \"%s\""), bp->iconName);
          }
@@ -180,27 +180,26 @@ void AddTrayButtonAction(TrayComponentType *cp,
 /** Set the size of a button tray component. */
 void SetSize(TrayComponentType *cp, int width, int height)
 {
-
    TrayButtonType *bp;
+   int labelWidth, labelHeight;
+   int iconWidth, iconHeight;
 
    bp = (TrayButtonType*)cp->object;
 
-   if(bp->icon) {
+   if(bp->label) {
+      labelWidth = GetStringWidth(FONT_TRAY, bp->label) + 6;
+      labelHeight = GetStringHeight(FONT_TRAY) + 6;
+   } else {
+      labelWidth = 4;
+      labelHeight = 4;
+   }
 
-      int labelWidth, labelHeight;
-      int iconWidth, iconHeight;
+   if(bp->icon && bp->icon->width && bp->icon->height) {
+      /* With an icon. */
       int ratio;
 
-      if(bp->label) {
-         labelWidth = GetStringWidth(FONT_TRAYBUTTON, bp->label) + 6;
-         labelHeight = GetStringHeight(FONT_TRAYBUTTON) + 6;
-      } else {
-         labelWidth = 4;
-         labelHeight = 4;
-      }
-
-      iconWidth = bp->icon->images->width;
-      iconHeight = bp->icon->images->height;
+      iconWidth = bp->icon->width;
+      iconHeight = bp->icon->height;
 
       /* Fixed point with 16 bit fraction. */
       ratio = (iconWidth << 16) / iconHeight;
@@ -219,20 +218,37 @@ void SetSize(TrayComponentType *cp, int width, int height)
          iconWidth = (iconHeight * ratio) >> 16;
          width = iconWidth + labelWidth;
 
+      } else {
+
+         /* Use best size. */
+         height = Max(labelHeight, iconHeight + 4);
+         iconWidth = ((height - 4) * ratio) >> 16;
+         width = iconWidth + labelWidth;
+
       }
 
-      cp->width = width;
-      cp->height = height;
-
+   } else {
+      /* No icon. */
+      if(width > 0) {
+         height = labelHeight;
+      } else if(height > 0) {
+         width = labelWidth;
+      } else {
+         height = labelHeight;
+         width = labelWidth;
+      }
    }
 
+   cp->width = width;
+   cp->height = height;
+
 }
 
 /** Initialize a button tray component. */
 void Create(TrayComponentType *cp)
 {
    cp->pixmap = JXCreatePixmap(display, rootWindow,
-                               cp->width, cp->height, rootVisual.depth);
+                               cp->width, cp->height, rootDepth);
    Draw(cp);
 }
 
@@ -261,7 +277,7 @@ void Draw(TrayComponentType *cp)
    bp = (TrayButtonType*)cp->object;
 
    ClearTrayDrawable(cp);
-   ResetButton(&button, cp->pixmap, &rootVisual);
+   ResetButton(&button, cp->pixmap);
    if(cp->grabbed) {
       button.type = BUTTON_TRAY_ACTIVE;
    } else {
@@ -269,9 +285,10 @@ void Draw(TrayComponentType *cp)
    }
    button.width = cp->width;
    button.height = cp->height;
+   button.border = settings.trayDecorations == DECO_MOTIF;
    button.x = 0;
    button.y = 0;
-   button.font = FONT_TRAYBUTTON;
+   button.font = FONT_TRAY;
    button.text = bp->label;
    button.icon = bp->icon;
    DrawButton(&button);
@@ -318,7 +335,7 @@ void SignalTrayButton(const TimeType *now, int x, int y, Window w, void *data)
       abs(bp->mousex - x) < settings.doubleClickDelta &&
       abs(bp->mousey - y) < settings.doubleClickDelta) {
       if(GetTimeDifference(now, &bp->mouseTime) >= settings.popupDelay) {
-         ShowPopup(x, y, popup);
+         ShowPopup(x, y, popup, POPUP_BUTTON);
       }
    }
 }
@@ -331,4 +348,3 @@ void ValidateTrayButtons(void)
       ValidateActions(bp->actions);
    }
 }
-
